You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@jmeter.apache.org by pm...@apache.org on 2016/01/06 22:03:36 UTC

svn commit: r1723411 - in /jmeter/trunk: bin/jmeter.properties src/core/org/apache/jmeter/reporters/Summariser.java

Author: pmouawad
Date: Wed Jan  6 21:03:36 2016
New Revision: 1723411

URL: http://svn.apache.org/viewvc?rev=1723411&view=rev
Log:
[Bug 55512] Summariser should be enabled by default in Non GUI mode
Restore 30 seconds as interval
Bugzilla Id: 55512

Modified:
    jmeter/trunk/bin/jmeter.properties
    jmeter/trunk/src/core/org/apache/jmeter/reporters/Summariser.java

Modified: jmeter/trunk/bin/jmeter.properties
URL: http://svn.apache.org/viewvc/jmeter/trunk/bin/jmeter.properties?rev=1723411&r1=1723410&r2=1723411&view=diff
==============================================================================
--- jmeter/trunk/bin/jmeter.properties (original)
+++ jmeter/trunk/bin/jmeter.properties Wed Jan  6 21:03:36 2016
@@ -840,8 +840,8 @@ wmlParser.types=text/vnd.wap.wml
 # (applies to non-GUI mode only)
 summariser.name=summary
 #
-# interval between summaries (in seconds) default 3 minutes
-#summariser.interval=180
+# interval between summaries (in seconds) default 30 seconds
+#summariser.interval=30
 #
 # Write messages to log file
 #summariser.log=true

Modified: jmeter/trunk/src/core/org/apache/jmeter/reporters/Summariser.java
URL: http://svn.apache.org/viewvc/jmeter/trunk/src/core/org/apache/jmeter/reporters/Summariser.java?rev=1723411&r1=1723410&r2=1723411&view=diff
==============================================================================
--- jmeter/trunk/src/core/org/apache/jmeter/reporters/Summariser.java (original)
+++ jmeter/trunk/src/core/org/apache/jmeter/reporters/Summariser.java Wed Jan  6 21:03:36 2016
@@ -71,8 +71,8 @@ public class Summariser extends Abstract
 
     private static final Logger log = LoggingManager.getLoggerForClass();
 
-    /** interval between summaries (in seconds) default 3 minutes */
-    private static final long INTERVAL = JMeterUtils.getPropDefault("summariser.interval", 3 * 60); //$NON-NLS-1$
+    /** interval between summaries (in seconds) default 30 seconds */
+    private static final long INTERVAL = JMeterUtils.getPropDefault("summariser.interval", 30); //$NON-NLS-1$
 
     /** Write messages to log file ? */
     private static final boolean TOLOG = JMeterUtils.getPropDefault("summariser.log", true); //$NON-NLS-1$



Re: svn commit: r1723411 - in /jmeter/trunk: bin/jmeter.properties src/core/org/apache/jmeter/reporters/Summariser.java

Posted by Philippe Mouawad <ph...@gmail.com>.
On Thu, Jan 7, 2016 at 5:29 AM, Rainer Jung <ra...@kippdata.de> wrote:

> Am 07.01.2016 um 04:05 schrieb sebb:
>
>> On 6 January 2016 at 21:03,  <pm...@apache.org> wrote:
>>
>>> Author: pmouawad
>>> Date: Wed Jan  6 21:03:36 2016
>>> New Revision: 1723411
>>>
>>> URL: http://svn.apache.org/viewvc?rev=1723411&view=rev
>>> Log:
>>> [Bug 55512] Summariser should be enabled by default in Non GUI mode
>>> Restore 30 seconds as interval
>>>
>>
>> -1
>>
>> I don't agree with this for two reasons:
>> 1) it's nothing to do with enabling the the Summariser, so would need
>> a different bugzilla (if agreed)
>>
>
If you read the bugzilla, I asked in the 3rd comment about this change to
30s and did it then. So it is in the bugzilla.

>
> <Nitpicking>That change from 3 minutes to 30 seconds happened back in 2013
> and would have needed a different BZ by then. It was then released. One
> could thus argue, that your change from 30 seconds back to 3 minutes would
> have needed a BZ</Nitpicking>
>
> 2) The interval is far too short as a default; it will cause log files
>> to be much longer.
>>
>
> Since the value is configurable, it is a question about the best default.
> IMHO the best use case of the summariser is for human feedback during the
> test run. All other test analysis is better done based on the log protocol,
> reporting etc. For this live feedback I personally prefer a cycle where I
> don't have to wait so long. So I really liked the 30 seconds and for me 3
> minutes would be far too long.
>
I Agree with Rainer.
Lot of people do short test to check the Non Gui setup and want to see
results rapidly. Setting it to 180s might not show them anything, not
making them aware that this feature exists.
We do a lot of Huge Load Tests with 30s interval and the impact on log
files is nothing compared to the size of output files, besides it is very
useful as you detect much earlier any issue in application behaviour and
can look at it.



>
> Regards,
>
> Rainer
>



-- 
Cordialement.
Philippe Mouawad.

Re: svn commit: r1723411 - in /jmeter/trunk: bin/jmeter.properties src/core/org/apache/jmeter/reporters/Summariser.java

Posted by Milamber <mi...@apache.org>.

On 07/01/2016 04:29, Rainer Jung wrote:
>> 2) The interval is far too short as a default; it will cause log files
>> to be much longer.
>
> Since the value is configurable, it is a question about the best 
> default. IMHO the best use case of the summariser is for human 
> feedback during the test run. All other test analysis is better done 
> based on the log protocol, reporting etc. For this live feedback I 
> personally prefer a cycle where I don't have to wait so long. So I 
> really liked the 30 seconds and for me 3 minutes would be far too long. 

Yes, for me, the 30 sec interval is the very valuable default value. 
Before the 2013's change (180 to 30), I always change this properties to 
30 secs in my user.properties.

I never use the jmeter.log to check the summariser values (always 
following the values in live during load test)

Milamber


Re: svn commit: r1723411 - in /jmeter/trunk: bin/jmeter.properties src/core/org/apache/jmeter/reporters/Summariser.java

Posted by Rainer Jung <ra...@kippdata.de>.
Am 07.01.2016 um 04:05 schrieb sebb:
> On 6 January 2016 at 21:03,  <pm...@apache.org> wrote:
>> Author: pmouawad
>> Date: Wed Jan  6 21:03:36 2016
>> New Revision: 1723411
>>
>> URL: http://svn.apache.org/viewvc?rev=1723411&view=rev
>> Log:
>> [Bug 55512] Summariser should be enabled by default in Non GUI mode
>> Restore 30 seconds as interval
>
> -1
>
> I don't agree with this for two reasons:
> 1) it's nothing to do with enabling the the Summariser, so would need
> a different bugzilla (if agreed)

<Nitpicking>That change from 3 minutes to 30 seconds happened back in 
2013 and would have needed a different BZ by then. It was then released. 
One could thus argue, that your change from 30 seconds back to 3 minutes 
would have needed a BZ</Nitpicking>

> 2) The interval is far too short as a default; it will cause log files
> to be much longer.

Since the value is configurable, it is a question about the best 
default. IMHO the best use case of the summariser is for human feedback 
during the test run. All other test analysis is better done based on the 
log protocol, reporting etc. For this live feedback I personally prefer 
a cycle where I don't have to wait so long. So I really liked the 30 
seconds and for me 3 minutes would be far too long.

Regards,

Rainer

Re: svn commit: r1723411 - in /jmeter/trunk: bin/jmeter.properties src/core/org/apache/jmeter/reporters/Summariser.java

Posted by sebb <se...@gmail.com>.
On 6 January 2016 at 21:03,  <pm...@apache.org> wrote:
> Author: pmouawad
> Date: Wed Jan  6 21:03:36 2016
> New Revision: 1723411
>
> URL: http://svn.apache.org/viewvc?rev=1723411&view=rev
> Log:
> [Bug 55512] Summariser should be enabled by default in Non GUI mode
> Restore 30 seconds as interval

-1

I don't agree with this for two reasons:
1) it's nothing to do with enabling the the Summariser, so would need
a different bugzilla (if agreed)
2) The interval is far too short as a default; it will cause log files
to be much longer.

> Bugzilla Id: 55512
>
> Modified:
>     jmeter/trunk/bin/jmeter.properties
>     jmeter/trunk/src/core/org/apache/jmeter/reporters/Summariser.java
>
> Modified: jmeter/trunk/bin/jmeter.properties
> URL: http://svn.apache.org/viewvc/jmeter/trunk/bin/jmeter.properties?rev=1723411&r1=1723410&r2=1723411&view=diff
> ==============================================================================
> --- jmeter/trunk/bin/jmeter.properties (original)
> +++ jmeter/trunk/bin/jmeter.properties Wed Jan  6 21:03:36 2016
> @@ -840,8 +840,8 @@ wmlParser.types=text/vnd.wap.wml
>  # (applies to non-GUI mode only)
>  summariser.name=summary
>  #
> -# interval between summaries (in seconds) default 3 minutes
> -#summariser.interval=180
> +# interval between summaries (in seconds) default 30 seconds
> +#summariser.interval=30
>  #
>  # Write messages to log file
>  #summariser.log=true
>
> Modified: jmeter/trunk/src/core/org/apache/jmeter/reporters/Summariser.java
> URL: http://svn.apache.org/viewvc/jmeter/trunk/src/core/org/apache/jmeter/reporters/Summariser.java?rev=1723411&r1=1723410&r2=1723411&view=diff
> ==============================================================================
> --- jmeter/trunk/src/core/org/apache/jmeter/reporters/Summariser.java (original)
> +++ jmeter/trunk/src/core/org/apache/jmeter/reporters/Summariser.java Wed Jan  6 21:03:36 2016
> @@ -71,8 +71,8 @@ public class Summariser extends Abstract
>
>      private static final Logger log = LoggingManager.getLoggerForClass();
>
> -    /** interval between summaries (in seconds) default 3 minutes */
> -    private static final long INTERVAL = JMeterUtils.getPropDefault("summariser.interval", 3 * 60); //$NON-NLS-1$
> +    /** interval between summaries (in seconds) default 30 seconds */
> +    private static final long INTERVAL = JMeterUtils.getPropDefault("summariser.interval", 30); //$NON-NLS-1$
>
>      /** Write messages to log file ? */
>      private static final boolean TOLOG = JMeterUtils.getPropDefault("summariser.log", true); //$NON-NLS-1$
>
>